/*
 * Copyright (C) 2010 Teleal GmbH, Switzerland
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.teleal.cling.model;

import java.util.Date;

/**
 * @author Christian Bauer
 */
public class ExpirationDetails {

    public static final int UNLIMITED_AGE = 0;

    private int maxAgeSeconds = UNLIMITED_AGE;
    private long lastRefreshTimestampSeconds = getCurrentTimestampSeconds();

    public ExpirationDetails() {
    }

    public ExpirationDetails(int maxAgeSeconds) {
        this.maxAgeSeconds = maxAgeSeconds;
    }

    public int getMaxAgeSeconds() {
        return maxAgeSeconds;
    }

    public long getLastRefreshTimestampSeconds() {
        return lastRefreshTimestampSeconds;
    }

    public void setLastRefreshTimestampSeconds(long lastRefreshTimestampSeconds) {
        this.lastRefreshTimestampSeconds = lastRefreshTimestampSeconds;
    }

    public void stampLastRefresh() {
        setLastRefreshTimestampSeconds(getCurrentTimestampSeconds());
    }

    public boolean hasExpired() {
        return hasExpired(false);
    }

    public boolean hasExpired(boolean halfTime) {
        return maxAgeSeconds != UNLIMITED_AGE &&
                (getLastRefreshTimestampSeconds() + (getMaxAgeSeconds()/(halfTime ? 2 : 1))) < getCurrentTimestampSeconds();
    }

    public long getSecondsUntilExpiration() {
        return maxAgeSeconds == UNLIMITED_AGE
                ? Integer.MAX_VALUE
                : (getLastRefreshTimestampSeconds() + getMaxAgeSeconds()) - getCurrentTimestampSeconds();
    }

    protected long getCurrentTimestampSeconds() {
        return new Date().getTime()/1000;
    }

    @Override
    public String toString() {
        return "(" + getClass().getSimpleName() + ")" + " MAX AGE: " + getMaxAgeSeconds();
    }
}
