/*
 * Copyright (C) 2010 Teleal GmbH, Switzerland
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.teleal.cling.test.data;

import org.teleal.cling.model.Resource;
import org.teleal.cling.model.meta.Device;
import org.teleal.cling.model.meta.DeviceIdentity;
import org.teleal.cling.model.meta.LocalService;

import java.net.URI;

import static org.testng.Assert.assertEquals;

/**
 * @author Christian Bauer
 */
public class SampleDeviceRootLocal extends SampleDeviceRoot {

    public SampleDeviceRootLocal(DeviceIdentity identity, LocalService service, Device embeddedDevice) {
        super(identity, service, embeddedDevice);
    }

    public static void assertLocalResourcesMatch(Resource[] resources){
        assertEquals(
                getLocalResource(resources, URI.create("/upnp/device/MY-DEVICE-123/desc.xml")).getType(),
                Resource.Type.DEVICE_DESCRIPTOR
        );
        assertEquals(
                getLocalResource(resources, URI.create("/upnp/device/MY-DEVICE-123/icon.png")).getType(),
                Resource.Type.ICON
        );
        assertEquals(
                getLocalResource(resources, URI.create("/upnp/device/MY-DEVICE-123/icon2.png")).getType(),
                Resource.Type.ICON
        );
        assertEquals(
                getLocalResource(resources, URI.create("/upnp/device/MY-DEVICE-123/service/upnp-org/MY-SERVICE-123/desc.xml")).getType(),
                Resource.Type.SERVICE_DESCRIPTOR
        );
        assertEquals(
                getLocalResource(resources, URI.create("/upnp/device/MY-DEVICE-123/service/upnp-org/MY-SERVICE-123/action")).getType(),
                Resource.Type.CONTROL
        );
        assertEquals(
                getLocalResource(resources, URI.create("/upnp/device/MY-DEVICE-123/service/upnp-org/MY-SERVICE-123/subscription")).getType(),
                Resource.Type.EVENT_SUBSCRIPTION
        );
        assertEquals(
                getLocalResource(resources, URI.create("/upnp/device/MY-DEVICE-456/icon3.png")).getType(),
                Resource.Type.ICON
        );
        assertEquals(
                getLocalResource(resources, URI.create("/upnp/device/MY-DEVICE-456/service/upnp-org/MY-SERVICE-456/desc.xml")).getType(),
                Resource.Type.SERVICE_DESCRIPTOR
        );
        assertEquals(
                getLocalResource(resources, URI.create("/upnp/device/MY-DEVICE-456/service/upnp-org/MY-SERVICE-456/action")).getType(),
                Resource.Type.CONTROL
        );
        assertEquals(
                getLocalResource(resources, URI.create("/upnp/device/MY-DEVICE-456/service/upnp-org/MY-SERVICE-456/subscription")).getType(),
                Resource.Type.EVENT_SUBSCRIPTION
        );
        assertEquals(
                getLocalResource(resources, URI.create("/upnp/device/MY-DEVICE-789/service/upnp-org/MY-SERVICE-789/desc.xml")).getType(),
                Resource.Type.SERVICE_DESCRIPTOR
        );
        assertEquals(
                getLocalResource(resources, URI.create("/upnp/device/MY-DEVICE-789/service/upnp-org/MY-SERVICE-789/action")).getType(),
                Resource.Type.CONTROL
        );
        assertEquals(
                getLocalResource(resources, URI.create("/upnp/device/MY-DEVICE-789/service/upnp-org/MY-SERVICE-789/subscription")).getType(),
                Resource.Type.EVENT_SUBSCRIPTION
        );

    }

}
