/*
 * Copyright (C) 2010 Teleal GmbH, Switzerland
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.teleal.cling.support.renderingcontrol.callback;

import java.util.logging.Logger;
import org.teleal.cling.controlpoint.ActionCallback;
import org.teleal.cling.model.action.ActionArgumentValue;
import org.teleal.cling.model.action.ActionException;
import org.teleal.cling.model.action.ActionInvocation;
import org.teleal.cling.model.meta.Service;
import org.teleal.cling.model.message.UpnpResponse;
import org.teleal.cling.model.types.UnsignedIntegerFourBytes;
import org.teleal.cling.support.renderingcontrol.Channel;

/**
 *
 * @author Christian Bauer
 */
public abstract class GetMuteActionCallback extends ActionCallback {

    private static Logger log = Logger.getLogger(GetMuteActionCallback.class.getName());

    public GetMuteActionCallback(Service service) {
        this(new UnsignedIntegerFourBytes(0), service);
    }
    public GetMuteActionCallback(UnsignedIntegerFourBytes instanceId, Service service) {
        super(new ActionInvocation(service.getAction("GetMute")));

        try {
            getActionInvocation().getInput().addValue(instanceId);
            getActionInvocation().getInput().addValue(Channel.Master.toString());
        } catch (ActionException ex) {
            throw new RuntimeException(ex);
        }
    }

    public void success(ActionInvocation actionInvocation) {
        ActionArgumentValue[] output = actionInvocation.getOutput().getValues();

        boolean currentMute = (Boolean)output[0].getValue();
        received(actionInvocation, currentMute);
    }

    public void failure(ActionInvocation actionInvocation, UpnpResponse operation) {
        failure(createDefaultFailureMessage(actionInvocation, operation));
    }

    public abstract void received(ActionInvocation actionInvocation, boolean currentMute);
    public abstract void failure(String failureMessage);

}