/*
 * Copyright (C) 2010 Teleal GmbH, Switzerland
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.teleal.cling.support.renderingcontrol.callback;

import java.util.logging.Logger;
import org.teleal.cling.controlpoint.ActionCallback;
import org.teleal.cling.model.action.ActionArgumentValue;
import org.teleal.cling.model.action.ActionException;
import org.teleal.cling.model.action.ActionInvocation;
import org.teleal.cling.model.message.UpnpResponse;
import org.teleal.cling.model.meta.Service;
import org.teleal.cling.model.types.ErrorCode;
import org.teleal.cling.model.types.UnsignedIntegerFourBytes;
import org.teleal.cling.support.renderingcontrol.Channel;

/**
 *
 * @author Christian Bauer
 */
public abstract class GetVolumeActionCallback extends ActionCallback {

    private static Logger log = Logger.getLogger(GetVolumeActionCallback.class.getName());

    public GetVolumeActionCallback(Service service) {
        this(new UnsignedIntegerFourBytes(0), service);
    }

    public GetVolumeActionCallback(UnsignedIntegerFourBytes instanceId, Service service) {
        super(new ActionInvocation(service.getAction("GetVolume")));

        try {
            getActionInvocation().getInput().addValue(instanceId);
            getActionInvocation().getInput().addValue(Channel.Master.toString());
        } catch (ActionException ex) {
            throw new RuntimeException(ex);
        }
    }

    public void success(ActionInvocation actionInvocation) {
        ActionArgumentValue[] output = actionInvocation.getOutput().getValues();

        boolean ok = true;
        int currentVolume = 0;
        try {
            currentVolume = Integer.valueOf(output[0].getValue().toString()); // UnsignedIntegerTwoBytes...
        } catch (Exception ex) {
            actionInvocation.setFailure(
                    new ActionException(ErrorCode.ACTION_FAILED, "Can't parse ProtocolInfo response: " + ex, ex)
            );
            failure(actionInvocation, null);
            ok = false;
        }
        if (ok) received(actionInvocation, currentVolume);
    }

    public void failure(ActionInvocation actionInvocation, UpnpResponse operation) {
        failure(createDefaultFailureMessage(actionInvocation, operation));
    }

    public abstract void received(ActionInvocation actionInvocation, int currentVolume);
    public abstract void failure(String failureMessage);

}